@@ -1,4 +1,4 @@
-/* $Id: nano.c,v 1.144.2.7 2001/07/01 04:28:45 astyanax Exp $ */
+/* $Id: nano.c,v 1.144.2.10 2001/08/17 00:03:40 astyanax Exp $ */
 /**************************************************************************
  *   nano.c                                                               *
  *                                                                        *
@@ -2116,6 +2116,7 @@ void do_toggle(int which)
     switch (toggles[which].val) {
     case TOGGLE_PICOMODE_KEY:
 	shortcut_init(0);
+	SET(CLEAR_BACKUPSTRING);
 	display_main_list();
 	break;
     case TOGGLE_SUSPEND_KEY:
@@ -2533,6 +2534,14 @@ int main(int argc, char *argv[])
 		    kbinput = KEY_NPAGE;
 		    wgetch(edit);
 		    break;
+		case '7':
+		    kbinput = KEY_HOME;
+		    wgetch(edit);
+		    break;
+		case '8':
+		    kbinput = KEY_END;
+		    wgetch(edit);
+		    break;
 		case '[':	/* Alt-[-[-[A-E], F1-F5 in linux console */
 		    kbinput = wgetch(edit);
 		    if (kbinput >= 'A' && kbinput <= 'E')
