@@ -1,4 +1,4 @@
-/* $Id: search.c,v 1.56.2.3 2001/05/05 17:38:31 astyanax Exp $ */
+/* $Id: search.c,v 1.56.2.5 2001/08/17 00:08:40 astyanax Exp $ */
 /**************************************************************************
  *   search.c                                                             *
  *                                                                        *
@@ -82,6 +82,15 @@ int search_init(int replacing)
     buf = nmalloc(strlen(last_search) + 5);
     buf[0] = 0;
 
+
+    /* Clear the backupstring if we've changed from Pico mode to regular
+	mode */
+    if (ISSET(CLEAR_BACKUPSTRING)) {
+	free(backupstring);
+	backupstring = NULL;
+	UNSET(CLEAR_BACKUPSTRING);
+    }
+	
      /* Okay, fun time.  backupstring is our holder for what is being 
 	returned from the statusq call.  Using answer for this would be tricky.
 	Here, if we're using PICO_MODE, we only want nano to put the
