@@ -1,4 +1,4 @@
-/* $Id: winio.c,v 1.85.2.2 2001/05/05 17:38:31 astyanax Exp $ */
+/* $Id: winio.c,v 1.85.2.3 2001/08/17 00:03:40 astyanax Exp $ */
 /**************************************************************************
  *   winio.c                                                              *
  *                                                                        *
@@ -454,10 +454,8 @@ int nanogetstr(int allowtabs, char *buf, char *def, shortcut s[], int slen,
     answer = mallocstrcpy(answer, inputbuf);
     free(inputbuf);
 
-    /* Now that the text is editable instead of bracketed, we have to 
-       check for answer == def, instead of answer == "" */
-    if  (((ISSET(PICO_MODE)) && !strcmp(answer, "")) || 
-	((!ISSET(PICO_MODE)) && !strcmp(answer, def)))
+    /* In pico mode, just check for a blank answer here */
+    if  (((ISSET(PICO_MODE)) && !strcmp(answer, "")))
 	return -2;
     else
 	return 0;
